From 56c4a2c236b9372495d8374673932f4a069b2964 Mon Sep 17 00:00:00 2001
From: hinto-janaiyo <hinto.janaiyo@protonmail.com>
Date: Tue, 22 Nov 2022 23:10:06 -0500
Subject: [PATCH] node: add plowsof to community node list

---
 README.md   |  2 ++
 src/node.rs | 16 +++++++++++-----
 2 files changed, 13 insertions(+), 5 deletions(-)

diff --git a/README.md b/README.md
index 3baa6aa..4fa4faf 100644
--- a/README.md
+++ b/README.md
@@ -65,6 +65,8 @@ With Monero GUI managing the Monero node on one side and Gupax managing P2Pool/X
 | MajesticBankIs | node.majesticbank.is             | 18089    |
 | MajesticBankSu | node.majesticbank.su             | 18089    |
 | Monerujo       | nodex.monerujo.io                | 18081    |
+| Plowsof1       | node.monerodevs.org              | 18089    |
+| Plowsof2       | node2.monerodevs.org             | 18089    |
 | Rino           | node.community.rino.io           | 18081    |
 | Seth           | node.sethforprivacy.com          | 18089    |
 | Singapore      | singapore.node.xmr               | 18081    |
diff --git a/src/node.rs b/src/node.rs
index 5dae0a2..a676f30 100644
--- a/src/node.rs
+++ b/src/node.rs
@@ -27,7 +27,7 @@ use hyper::{
 };
 
 //---------------------------------------------------------------------------------------------------- Node list
 // Community Monerod nodes. All of these have ZMQ on 18083.
 // Adding/removing nodes will need changes to pretty
 // much all the code in this file, and the code that
 // handles the actual Enum selector in the P2Pool tab.
@@ -41,6 +41,8 @@ pub const FEATHER_2: &'static str = "selsta2.featherwallet.net:18081";
 pub const MAJESTICBANK_IS: &'static str = "node.majesticbank.is:18089";
 pub const MAJESTICBANK_SU: &'static str = "node.majesticbank.su:18089";
 pub const MONERUJO: &'static str = "nodex.monerujo.io:18081";
+pub const PLOWSOF_1: &'static str = "node.monerodevs.org:18089";
+pub const PLOWSOF_2: &'static str = "node2.monerodevs.org:18089";
 pub const RINO: &'static str = "node.community.rino.io:18081";
 pub const SETH: &'static str = "node.sethforprivacy.com:18089";
 pub const SUPPORTXMR: &'static str = "node.supportxmr.com:18081";
@@ -48,15 +50,15 @@ pub const SUPPORTXMR_IR: &'static str = "node.supportxmr.ir:18081";
 pub const SINGAPORE: &'static str = "singapore.node.xmr.pm:18089";
 pub const XMRVSBEAST: &'static str = "p2pmd.xmrvsbeast.com:18081";
 
-pub const NODE_IPS: [&'static str; 16] = [
+pub const NODE_IPS: [&'static str; 18] = [
 	C3POOL,CAKE,CAKE_EU,CAKE_UK,CAKE_US,FEATHER_1,FEATHER_2,MAJESTICBANK_IS,MAJESTICBANK_SU,
-	MONERUJO,RINO,SETH,SUPPORTXMR,SUPPORTXMR_IR,SINGAPORE,XMRVSBEAST,
+	MONERUJO,PLOWSOF_1,PLOWSOF_2,RINO,SETH,SUPPORTXMR,SUPPORTXMR_IR,SINGAPORE,XMRVSBEAST,
 ];
 
 #[derive(Copy,Clone,Eq,PartialEq,Debug,Deserialize,Serialize)]
 pub enum NodeEnum {
-	C3pool,Cake,CakeEu,CakeUk,CakeUs,MajesticBankIs,MajesticBankSu,Monerujo,
-	Rino,Feather1,Feather2,Seth,SupportXmr,SupportXmrIr,Singapore,XmrVsBeast,
+	C3pool,Cake,CakeEu,CakeUk,CakeUs,MajesticBankIs,MajesticBankSu,Monerujo,Plowsof1,
+	Plowsof2,Rino,Feather1,Feather2,Seth,SupportXmr,SupportXmrIr,Singapore,XmrVsBeast,
 }
 
 impl std::fmt::Display for NodeEnum {
@@ -104,6 +106,8 @@ pub fn ip_to_enum(ip: &'static str) -> NodeEnum {
 		MAJESTICBANK_IS => MajesticBankIs,
 		MAJESTICBANK_SU => MajesticBankSu,
 		MONERUJO        => Monerujo,
+		PLOWSOF_1       => Plowsof1,
+		PLOWSOF_2       => Plowsof2,
 		RINO            => Rino,
 		SETH            => Seth,
 		SINGAPORE       => Singapore,
@@ -125,6 +129,8 @@ pub fn enum_to_ip(node: NodeEnum) -> &'static str {
 		MajesticBankIs => MAJESTICBANK_IS,
 		MajesticBankSu => MAJESTICBANK_SU,
 		Monerujo       => MONERUJO,
+		Plowsof1       => PLOWSOF_1,
+		Plowsof2       => PLOWSOF_2,
 		Rino           => RINO,
 		Seth           => SETH,
 		Singapore      => SINGAPORE,
@@ -27,7 +27,7 @@ use hyper::{
 
 //---------------------------------------------------------------------------------------------------- Node list
-// Community Monerod nodes. All of these have ZMQ on 18083.
+// Community Monerod nodes. ALL BUT ONE of these have ZMQ on 18083 (plowsof pls)
 // Adding/removing nodes will need changes to pretty
 // much all the code in this file, and the code that